summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoUnitWidgets.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /lib/kofficeui/KoUnitWidgets.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficeui/KoUnitWidgets.h')
-rw-r--r--lib/kofficeui/KoUnitWidgets.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/lib/kofficeui/KoUnitWidgets.h b/lib/kofficeui/KoUnitWidgets.h
index dbdcb9c0..80db554d 100644
--- a/lib/kofficeui/KoUnitWidgets.h
+++ b/lib/kofficeui/KoUnitWidgets.h
@@ -44,7 +44,7 @@ class KoUnitDoubleBase;
class KOFFICEUI_EXPORT KoUnitDoubleValidator : public KDoubleValidator
{
public:
- KoUnitDoubleValidator( KoUnitDoubleBase *base, TQObject *tqparent, const char *name = 0 );
+ KoUnitDoubleValidator( KoUnitDoubleBase *base, TQObject *parent, const char *name = 0 );
virtual TQValidator::State validate( TQString &, int & ) const;
@@ -109,9 +109,9 @@ class KOFFICEUI_EXPORT KoUnitDoubleSpinBox : public KDoubleSpinBox, public KoUni
Q_OBJECT
TQ_OBJECT
public:
- KoUnitDoubleSpinBox( TQWidget *tqparent = 0L, const char *name = 0L );
+ KoUnitDoubleSpinBox( TQWidget *parent = 0L, const char *name = 0L );
// lower, upper, step and value are in pt
- KoUnitDoubleSpinBox( TQWidget *tqparent, double lower, double upper, double step, double value = 0.0,
+ KoUnitDoubleSpinBox( TQWidget *parent, double lower, double upper, double step, double value = 0.0,
KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
// added so the class can be used in .ui files(by Tymoteusz Majewski, maju7@o2.pl)
virtual void changeValue( double );
@@ -136,7 +136,7 @@ public:
void setMinMaxStep( double min, double max, double step );
signals:
/// emitted like valueChanged in the tqparent, but this one emits the point value
void valueChangedPt( double );
@@ -160,8 +160,8 @@ class KOFFICEUI_EXPORT KoUnitDoubleLineEdit : public KLineEdit, public KoUnitDou
Q_OBJECT
TQ_OBJECT
public:
- KoUnitDoubleLineEdit( TQWidget *tqparent = 0L, const char *name = 0L );
- KoUnitDoubleLineEdit( TQWidget *tqparent, double lower, double upper, double value = 0.0, KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
+ KoUnitDoubleLineEdit( TQWidget *parent = 0L, const char *name = 0L );
+ KoUnitDoubleLineEdit( TQWidget *parent, double lower, double upper, double value = 0.0, KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
virtual void changeValue( double );
virtual void setUnit( KoUnit::Unit = KoUnit::U_PT );
@@ -189,8 +189,8 @@ class KOFFICEUI_EXPORT KoUnitDoubleComboBox : public KComboBox, public KoUnitDou
Q_OBJECT
TQ_OBJECT
public:
- KoUnitDoubleComboBox( TQWidget *tqparent = 0L, const char *name = 0L );
- KoUnitDoubleComboBox( TQWidget *tqparent, double lower, double upper, double value = 0.0, KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
+ KoUnitDoubleComboBox( TQWidget *parent = 0L, const char *name = 0L );
+ KoUnitDoubleComboBox( TQWidget *parent, double lower, double upper, double value = 0.0, KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
virtual void changeValue( double );
void updateValue( double );
@@ -226,8 +226,8 @@ class KOFFICEUI_EXPORT KoUnitDoubleSpinComboBox : public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- KoUnitDoubleSpinComboBox( TQWidget *tqparent = 0L, const char *name = 0L );
- KoUnitDoubleSpinComboBox( TQWidget *tqparent, double lower, double upper, double step, double value = 0.0, KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
+ KoUnitDoubleSpinComboBox( TQWidget *parent = 0L, const char *name = 0L );
+ KoUnitDoubleSpinComboBox( TQWidget *parent, double lower, double upper, double step, double value = 0.0, KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
void insertItem( double, int index = -1 );
void updateValue( double );
@@ -136,7 +136,7 @@ public:
void setMinMaxStep( double min, double max, double step );
signals:
- /// emitted like valueChanged in the tqparent, but this one emits the point value
+ /// emitted like valueChanged in the parent, but this one emits the point value
void valueChangedPt( double );